@@ -194,13 +194,15 @@ def release_desktop(close_projects=True, close_desktop=True):
                 desktop.CloseProject(project)
         pid = _main.oDesktop.GetProcessID()
         if settings.aedt_version >= "2022.2" and settings.use_grpc_api and not is_ironpython:
-            if _check_grpc_port(settings.port, settings.machine):
+            try:
                 import ScriptEnv
 
                 if close_desktop:
                     ScriptEnv.Shutdown()
                 else:
                     ScriptEnv.Release()
+            except:
+                pass
             _delete_objects()
             return True
         elif not inside_desktop:
@@ -748,18 +750,6 @@ class Desktop(object):
                 os.environ["LD_LIBRARY_PATH"] = os.path.join(base_path, "defer")
             pyaedt_path = os.path.realpath(os.path.join(os.path.dirname(os.path.realpath(__file__)), ".."))
             os.environ["PATH"] = pyaedt_path + os.pathsep + os.environ["PATH"]
-        import ctypes
-
-        self._main.library_aedt = ctypes.cdll.LoadLibrary(os.path.join(base_path, "PyDesktopPlugin.dll"))
-
-        # do things with lib_MyClass
-
-        if __name__ == "__main__":
-            lib = ctypes.cdll.LoadLibrary("./mylib.so")
-
-            # do things with lib_MyClass
-
-            ctypesCloseLibrary(lib)
 
         import ScriptEnv
 
