@@ -5,7 +5,6 @@ import math
 
 from pyaedt.edb_core.edb_data.simulation_configuration import SimulationConfiguration
 from pyaedt.edb_core.edb_data.sources import ExcitationDifferential
-from pyaedt.edb_core.general import convert_netdict_to_pydict
 from pyaedt.edb_core.general import convert_py_list_to_net_list
 from pyaedt.edb_core.general import convert_pytuple_to_nettuple
 from pyaedt.generic.constants import RadiationBoxType
@@ -13,7 +12,7 @@ from pyaedt.generic.constants import SweepType
 from pyaedt.generic.general_methods import generate_unique_name
 from pyaedt.generic.general_methods import is_ironpython
 from pyaedt.generic.general_methods import pyaedt_function_handler
-from pyaedt.modeler.GeometryOperators import GeometryOperators
+from pyaedt.modeler.geometry_operators import GeometryOperators
 
 
 class EdbHfss(object):
@@ -29,31 +28,6 @@ class EdbHfss(object):
     def __init__(self, p_edb):
         self._pedb = p_edb
 
-    @property
-    def _hfss_terminals(self):
-        edblib = self._pedb.edblib
-        return edblib.HFSS3DLayout.HFSSTerminalMethods
-
-    @property
-    def _hfss_ic_methods(self):
-        edblib = self._pedb.edblib
-        return edblib.HFSS3DLayout.ICMethods
-
-    @property
-    def _hfss_setup(self):
-        edblib = self._pedb.edblib
-        return edblib.HFSS3DLayout.HFSSSetup
-
-    @property
-    def _hfss_mesh_setup(self):
-        edblib = self._pedb.edblib
-        return edblib.HFSS3DLayout.Meshing
-
-    @property
-    def _sweep_methods(self):
-        edblib = self._pedb.edblib
-        return edblib.SimulationSetup.SweepMethods
-
     @property
     def _logger(self):
         return self._pedb.logger
@@ -119,11 +93,14 @@ class EdbHfss(object):
         """
         if not terminal_name:
             terminal_name = generate_unique_name("Terminal_")
-
-        point_on_edge = self._edb.Geometry.PointData(
-            self._get_edb_value(point_on_edge[0]), self._get_edb_value(point_on_edge[1])
-        )
-        prim = [i for i in self._pedb.core_primitives.primitives if i.id == prim_id][0].primitive_object
+        if not isinstance(point_on_edge, self._edb.Geometry.PointData):
+            point_on_edge = self._edb.Geometry.PointData(
+                self._get_edb_value(point_on_edge[0]), self._get_edb_value(point_on_edge[1])
+            )
+        if hasattr(prim_id, "GetId"):
+            prim = prim_id
+        else:
+            prim = [i for i in self._pedb.core_primitives.primitives if i.id == prim_id][0].primitive_object
         pos_edge = self._edb.Cell.Terminal.PrimitiveEdge.Create(prim, point_on_edge)
         pos_edge = convert_py_list_to_net_list(pos_edge, self._edb.Cell.Terminal.Edge)
         return self._edb.Cell.Terminal.EdgeTerminal.Create(
@@ -135,15 +112,16 @@ class EdbHfss(object):
         """Retrieve the trace width for traces with ports.
 
         Returns
-        -------
+        -------<
         dict
             Dictionary of trace width data.
         """
-        mesh = self._hfss_mesh_setup.GetMeshOperation(self._active_layout)
-        if mesh.Item1:
-            return convert_netdict_to_pydict(mesh.Item2)
-        else:
-            return {}
+        nets = {}
+        for net in self._pedb.excitations_nets:
+            smallest = self._pedb.core_nets.nets[net].get_smallest_trace_width()
+            if smallest < 1e10:
+                nets[net] = self._pedb.core_nets.nets[net].get_smallest_trace_width()
+        return nets
 
     @pyaedt_function_handler()
     def create_circuit_port_on_pin(self, pos_pin, neg_pin, impedance=50, port_name=None):
@@ -193,7 +171,7 @@ class EdbHfss(object):
         Returns
         -------
         str
-            Source Name
+            Source Name.
 
         Examples
         --------
@@ -304,7 +282,7 @@ class EdbHfss(object):
         Returns
         -------
         str
-            Port Name
+            The name of the port.
 
         Examples
         --------
@@ -355,7 +333,7 @@ class EdbHfss(object):
         Returns
         -------
         str
-            Source Name
+            Source Name.
 
         Examples
         --------
@@ -504,7 +482,7 @@ class EdbHfss(object):
             Coordinate of the point to define the edge terminal.
             The point must be close to the target edge but not on the two
             ends of the edge.
-        port_name :  str, optional
+        port_name : str, optional
             Name of the port. The default is ``None``.
         horizontal_extent_factor : int, float, optional
             Horizontal extent factor. The default value is ``5``.
@@ -516,7 +494,7 @@ class EdbHfss(object):
         Returns
         -------
         tuple
-            port_name, pyaedt.edb_core.edb_data.sources.ExcitationDifferential
+            The tuple contains: (port_name, pyaedt.edb_core.edb_data.sources.ExcitationDifferential).
 
         Examples
         --------
@@ -714,7 +692,7 @@ class EdbHfss(object):
         Returns
         -------
         tuple
-            Port name, pyaedt.edb_core.edb_data.sources.Excitation
+            The tuple contains: (Port name, pyaedt.edb_core.edb_data.sources.Excitation).
 
         Examples
         --------
@@ -945,26 +923,14 @@ class EdbHfss(object):
                                 if return_points_only:
                                     edges_pts.append(_pt)
                                 else:
-                                    try:
-                                        self._hfss_terminals.CreateEdgePort(
-                                            path, pt, reference_layer, port_name
-                                        )  # pragma: no cover
-                                    except:  # pragma: no cover
-                                        self._logger.warning(
-                                            "edge port creation failed on point {}, {}".format(str(pt[0]), str(pt[1]))
-                                        )
+                                    term = self._create_edge_terminal(path, pt, port_name)  # pragma no cover
+                                    term.SetReferenceLayer(reference_layer)  # pragma no cover
                         else:
                             if return_points_only:  # pragma: no cover
                                 edges_pts.append(_pt)
                             else:
-                                try:
-                                    self._hfss_terminals.CreateEdgePort(
-                                        path, pt, reference_layer, port_name
-                                    )  # pragma: no cover
-                                except:  # pragma: no cover
-                                    self._logger.warning(
-                                        "edge port creation failed on point {}, {}".format(str(pt[0]), str(pt[1]))
-                                    )
+                                term = self._create_edge_terminal(path, pt, port_name)
+                                term.SetReferenceLayer(reference_layer)
 
             if return_points_only:
                 return edges_pts
