@@ -31,6 +31,22 @@ def db10(x, inverse=True):
         return math.pow(10, x / 10.0)
 
 
+def dbw(x, inverse=True):
+    """Convert W to decimal and vice versa."""
+    if inverse:
+        return 10 * math.log10(x)
+    else:
+        return math.pow(10, x / 10.0)
+
+
+def dbm(x, inverse=True):
+    """Convert W to decimal and vice versa."""
+    if inverse:
+        return 10 * math.log10(x) + 30
+    else:
+        return math.pow(10, x / 10.0) / 1000
+
+
 def fah2kel(val, inverse=True):
     """Convert a temperature from Fahrenheit to Kelvin.
 
@@ -146,24 +162,43 @@ def unit_converter(values, unit_system="Length", input_units="meter", output_uni
         Converted value.
     """
     if unit_system in AEDT_UNITS:
-        if input_units not in AEDT_UNITS[unit_system] or output_units not in AEDT_UNITS[unit_system]:
-            warnings.warn("No units found")
+        if input_units not in AEDT_UNITS[unit_system]:
+            warnings.warn("Unknown units: '{}'".format(input_units))
+            return values
+        elif output_units not in AEDT_UNITS[unit_system]:
+            warnings.warn("Unknown units: '{}'".format(output_units))
             return values
         else:
-            if not isinstance(values, list):
+            input_is_list = isinstance(values, list)
+            if not input_is_list:
                 values = [values]
             converted_values = []
             for value in values:
                 if unit_system == "Temperature":
-                    value = AEDT_UNITS[unit_system][input_units][0](value, False)
-                    value = AEDT_UNITS[unit_system][output_units][0](value, output_units != "kel")
-                else:
+                    value = AEDT_UNITS[unit_system][input_units](value, False)
+                    value = AEDT_UNITS[unit_system][output_units](value, output_units != "kel")
+                elif not callable(AEDT_UNITS[unit_system][input_units]) and not callable(
+                    AEDT_UNITS[unit_system][output_units]
+                ):
                     value = value * AEDT_UNITS[unit_system][input_units] / AEDT_UNITS[unit_system][output_units]
+                elif not callable(AEDT_UNITS[unit_system][input_units]) and callable(
+                    AEDT_UNITS[unit_system][output_units]
+                ):
+                    value = value * AEDT_UNITS[unit_system][input_units]
+                    value = AEDT_UNITS[unit_system][output_units](value, True)
+                elif callable(AEDT_UNITS[unit_system][input_units]) and not callable(
+                    AEDT_UNITS[unit_system][output_units]
+                ):
+                    value = AEDT_UNITS[unit_system][input_units](value, False) / AEDT_UNITS[unit_system][output_units]
+                else:
+                    value = AEDT_UNITS[unit_system][input_units](value, False)
+                    value = AEDT_UNITS[unit_system][output_units](value, True)
+
                 converted_values.append(value)
-            if len(converted_values) == 1:
-                return converted_values[0]
-            else:
+            if input_is_list:
                 return converted_values
+            else:
+                return converted_values[0]
     warnings.warn("No system unit found")
     return values
 
@@ -350,9 +385,9 @@ AEDT_UNITS = {
         "kV": 1e3,
         "MegV": 1e6,
         "gV": 1e9,
-        "dBV": (db20,),
+        "dBV": db20,
     },
-    "Temperature": {"kel": lambda x, y: x, "cel": (cel2kel,), "fah": (fah2kel,)},
+    "Temperature": {"kel": lambda x, y: x, "cel": cel2kel, "fah": fah2kel},
     "Power": {
         "fW": 1e-15,
         "pW": 1e-12,
@@ -365,8 +400,8 @@ AEDT_UNITS = {
         "gW": 1e9,
         "Btu_per_hr": 3.4129693,
         "Btu_per_sec": 9.48047e-4,
-        "dBm": 30,
-        "dBW": 0,
+        "dBm": dbm,
+        "dBW": dbw,
         "HP": 1.34102e-3,
         "erg_per_sec": 1e7,
     },
